local Grid2StatusAuraGroupOptions = {}

local L = LibStub("AceLocale-3.0"):GetLocale("Grid2Options")
local LG = LibStub("AceLocale-3.0"):GetLocale("Grid2")


local newStatusAuraGroupName = ""

local function getAuraGroupKey(name)
	name = Grid2Options:GetValidatedName(name)
	if (name and name ~= "") then
		return "group-" .. name
	else
		return nil
	end
end

local function getNewStatusAuraGroupNameValue()
	return newStatusAuraGroupName
end

local function setNewStatusAuraGroupNameValue(info, auraGroupName)
	newStatusAuraGroupName = auraGroupName
end

local function NewStatusAuraGroup()
	local statusKey = getAuraGroupKey(newStatusAuraGroupName)
	if (statusKey) then
		local data = {newStatusAuraGroupName, true, 1, 1, 1,}

		local auraGroups = Grid2.db.profile.setup.auraGroups
		auraGroups[statusKey] = data

		local status = Grid2:SetupStatusAuraBuff(statusKey, data)
		Grid2Options:AddAura("Buff", statusKey, unpack(data))
		Grid2Options:AddElementSubType("status", "group", status, MakeStatusStandardBuffOptions(status))
	end
end

local function NewStatusAuraGroupDisabled()
	local statusKey = getAuraGroupKey(newStatusAuraGroupName)
	if (statusKey) then
		local buffs = Grid2.db.profile.setup.buffs
		if (not buffs[statusKey]) then
			return false
		end
	end
	return true
end

function ResetAuraGroupStatuses()
	local setup = Grid2.db.profile.setup
	Grid2:SetupDefaultStatus(setup)
	Grid2Frame:UpdateAllFrames()
	Grid2Options:AddSetupStatusesOptions(setup, true)
end

local function MakeStatusAuraGroupCreateOptions(reset)
	local options = {
		newStatusAuraGroupName = {
			type = "input",
			order = 1,
			width = "full",
			name = L["Name"],
			usage = L["<CharacterOnlyString>"],
			get = getNewStatusAuraGroupNameValue,
			set = setNewStatusAuraGroupNameValue,
		},
		newStatusAuraGroup = {
			type = "execute",
			order = 2,
			name = L["New Status"],
			desc = L["Create a new status."],
			func = NewStatusAuraGroup,
			disabled = NewStatusAuraGroupDisabled,
		},
		resetAuraGroupStatuses = {
			type = "execute",
			order = 11,
			name = L["Reset Statuses"],
			desc = L["Reset statuses to defaults."],
			func = ResetAuraGroupStatuses,
		},
	}
	return options
end


function Grid2StatusAuraGroupOptions:AddSetupStatusesOptions(setup, reset)
	local status, options

	options = MakeStatusAuraGroupCreateOptions()
	Grid2Options:AddElementSubTypeGroup("status", "group", options, reset)
	for statusKey, info in pairs(setup.auraGroups) do
		local status = Grid2.statuses[statusKey] -- TODO: fix names more better.  Type should not get baked in.
		if (status) then
			options = Grid2Options:MakeStatusStandardBuffOptions(status)
			Grid2Options:AddElementSubType("status", "group", status, options)
		end
	end
	for statusKey, info in pairs(setup.auraGroupDebuffs) do
		local status = Grid2.statuses[statusKey] -- TODO: fix names more better.  Type should not get baked in.
		if (status) then
			options = Grid2Options:MakeStatusStandardBuffOptions(status)
			Grid2Options:AddElementSubType("status", "group", status, options)
		end
	end

end

Grid2StatusAuraGroupOptions:AddSetupStatusesOptions(Grid2.db.profile.setup)
